@@ -1,4 +1,4 @@
-from azure.common.credentials import ServicePrincipalCredentials
+from azure.identity import ClientSecretCredential
 from azure.mgmt.datafactory import DataFactoryManagementClient
 from azure.mgmt.datafactory.models import RunFilterParameters
 import time
@@ -11,15 +11,16 @@ import functools as ft
 
 def authenticate(clientid, secret, tenant):
     """
-    Wraps the ServicePrincipalCredentials object. Handle these values with care! Best practice is to securely set them as environment variables in CI/CD pipelines or non-source control managed configs if testing locally.
+    Wraps the ClientSecretCredential object. Handle these values with care! Best practice is to securely set them as environment variables in CI/CD pipelines or non-source control managed configs if testing locally.
     """
-    credentials = ServicePrincipalCredentials(
+    credentials = ClientSecretCredential(
         client_id=clientid, 
-        secret=secret, 
-        tenant=tenant
+        client_secret=secret, 
+        tenant_id=tenant
     )
     return credentials
 
+
 def connect_to_df(credentials, subscription_id):
     """
     This connects to the specified data factory instance.
@@ -108,5 +109,4 @@ def process_attribute_search_string(attribute_search_base):
     else:
         print("Invalid construction for attribute search passed, setting attribute search to None")
         attribute_search = None   
-    return attribute_search
-
+    return attribute_search
\ No newline at end of file
